@@ -98,6 +98,12 @@ const config = {
           },
         ],
       },
+      announcementBar: {
+        content: `⛰️ <b><a target="_blank" href="https://git-cliff.org/blog/2.0.0">git-cliff v2.0</a> is now out!</b> 🥳️`,
+        backgroundColor: "#243840",
+        textColor: "#ffffff",
+        isCloseable: true,
+      },
       colorMode: {
         defaultMode: "dark",
         disableSwitch: false,
